Mesa (gallium-0.2): egl: switch to egl_glx. so as the default EGL driver for X.

Alan Hourihane alanh at kemper.freedesktop.org
Fri Sep 26 11:19:42 UTC 2008


Module: Mesa
Branch: gallium-0.2
Commit: cc6bdf49ca19c08d0c7134d2cd881b9c166cdc8a
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=cc6bdf49ca19c08d0c7134d2cd881b9c166cdc8a

Author: Alan Hourihane <alanh at tungstengraphics.com>
Date:   Fri Sep 26 12:18:59 2008 +0100

egl: switch to egl_glx.so as the default EGL driver for X.

---

 src/egl/main/eglx.c |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/src/egl/main/eglx.c b/src/egl/main/eglx.c
index 1bba149..50acc3a 100644
--- a/src/egl/main/eglx.c
+++ b/src/egl/main/eglx.c
@@ -44,7 +44,7 @@
 #include "eglx.h"
 
 
-static const char *DefaultDRIDriver = "egl_xdri";
+static const char *DefaultGLXDriver = "egl_glx";
 static const char *DefaultSoftDriver = "egl_softpipe";
 
 
@@ -52,7 +52,7 @@ static const char *DefaultSoftDriver = "egl_softpipe";
  * Given an X Display ptr (at dpy->Xdpy) try to determine the appropriate
  * device driver.  Return its name.
  *
  * This boils down to whether to use the egl_xdri.so driver which will
  * load a DRI driver or the egl_softpipe.so driver that'll do software
  * rendering on Xlib.
  */
@@ -82,9 +82,8 @@ _xeglChooseDriver(_EGLDisplay *dpy)
    /* See if we can choose a DRI/DRM driver */
    driverName = _eglChooseDRMDriver(screen);
    if (driverName) {
-      /* DRI is available */
       free((void *) driverName);
-      driverName = _eglstrdup(DefaultDRIDriver);
+      driverName = _eglstrdup(DefaultGLXDriver);
    }
    else {
       driverName = _eglstrdup(DefaultSoftDriver);
@@ -52,7 +52,7 @@ static const char *DefaultSoftDriver = "egl_softpipe";
  * device driver.  Return its name.
  *
- * This boils down to whether to use the egl_xdri.so driver which will
+ * This boils down to whether to use the egl_glx.so driver which will
  * load a DRI driver or the egl_softpipe.so driver that'll do software
  * rendering on Xlib.




More information about the mesa-commit mailing list